@@ -10,9 +10,9 @@ import {
   GridSelectionModel
 } from '@mui/x-data-grid';
 import * as React from 'react';
-import {Assignment} from '../../../model/assignment';
-import {Lecture} from '../../../model/lecture';
-import {utcToLocalFormat} from '../../../services/datetime.service';
+import { Assignment } from '../../../model/assignment';
+import { Lecture } from '../../../model/lecture';
+import { utcToLocalFormat } from '../../../services/datetime.service';
 import {
   Box,
   Button,
@@ -28,25 +28,25 @@ import {
   Tooltip,
   IconButton
 } from '@mui/material';
-import Select, {SelectChangeEvent} from '@mui/material/Select';
-import {getAllSubmissions} from '../../../services/submissions.service';
-import {AgreeDialog} from '../../util/dialog';
+import Select, { SelectChangeEvent } from '@mui/material/Select';
+import { getAllSubmissions } from '../../../services/submissions.service';
+import { AgreeDialog } from '../../util/dialog';
 import NavigateNextIcon from '@mui/icons-material/NavigateNext';
 import FileDownloadIcon from '@mui/icons-material/FileDownload';
-import {ModalTitle} from '../../util/modal-title';
-import {User} from '../../../model/user';
-import {Submission} from '../../../model/submission';
+import { ModalTitle } from '../../util/modal-title';
+import { User } from '../../../model/user';
+import { Submission } from '../../../model/submission';
 import {
   autogradeSubmission,
   generateFeedback,
   saveSubmissions
 } from '../../../services/grading.service';
 import LoadingOverlay from '../../util/overlay';
-import {ManualGrading} from './manual-grading';
+import { ManualGrading } from './manual-grading';
 import ReplayIcon from '@mui/icons-material/Replay';
-import {GlobalObjects} from '../../../index';
-import {enqueueSnackbar} from 'notistack';
-import {loadString, storeString} from "../../../services/storage.service";
+import { GlobalObjects } from '../../../index';
+import { enqueueSnackbar } from 'notistack';
+import { loadString, storeString } from '../../../services/storage.service';
 
 /**
  * Props for GradingComponent.
@@ -71,7 +71,8 @@ interface IRowValues extends Submission {
  */
 export const GradingComponent = (props: IGradingProps) => {
   const [option, setOption] = React.useState(
-    (loadString("grading-submission-option", null, props.assignment) || 'none') as 'none' | 'latest' | 'best'
+    (loadString('grading-submission-option', null, props.assignment) ||
+      'none') as 'none' | 'latest' | 'best'
   );
   const [showDialog, setShowDialog] = React.useState(false);
   const [showLogs, setShowLogs] = React.useState(false);
@@ -110,7 +111,6 @@ export const GradingComponent = (props: IGradingProps) => {
               props.assignment,
               getSubmissionFromRow(row)
             );
-            console.log('Autograded submission');
           });
         } catch (err) {
           console.error(err);
@@ -142,10 +142,9 @@ export const GradingComponent = (props: IGradingProps) => {
                 props.assignment.id,
                 row.id
               );
-              console.log('Autograded submission');
             })
           );
-          getAllSubmissions(props.lecture, props.assignment, option, true).then(
+          getAllSubmissions(props.lecture, props.assignment, option, true, true).then(
             response => {
               setRows(generateRows(response));
               enqueueSnackbar(
@@ -178,9 +177,6 @@ export const GradingComponent = (props: IGradingProps) => {
    * @param submissions submissions which are used to generate row objects
    */
   const generateRows = (submissions: Submission[]) => {
-    console.log('Submissions');
-    console.log(submissions);
-    console.log('option: ' + option);
     const rows: IRowValues[] = [];
     let id = 1;
     submissions.forEach((sub: Submission) => {
@@ -197,7 +193,6 @@ export const GradingComponent = (props: IGradingProps) => {
         score: sub.score
       });
     });
-    console.log(rows);
     return rows;
   };
 
@@ -216,13 +211,18 @@ export const GradingComponent = (props: IGradingProps) => {
    */
   const handleChange = (event: SelectChangeEvent) => {
     setOption(event.target.value as 'none' | 'latest' | 'best');
-    storeString("grading-submission-option", event.target.value, null, props.assignment);
+    storeString(
+      'grading-submission-option',
+      event.target.value,
+      null,
+      props.assignment
+    );
   };
   /**
    * Updates submissions and rows.
    */
   const updateSubmissions = () => {
-    getAllSubmissions(props.lecture, props.assignment, option, true).then(
+    getAllSubmissions(props.lecture, props.assignment, option, true, true).then(
       response => {
         setRows(generateRows(response));
         setSubmissions(response);
@@ -271,9 +271,9 @@ export const GradingComponent = (props: IGradingProps) => {
   };
 
   const columns = [
-    {field: 'sub_id', headerName: 'No.', width: 110},
-    {field: 'username', headerName: 'User', width: 130},
-    {field: 'submitted_at', headerName: 'Date', width: 170},
+    { field: 'sub_id', headerName: 'No.', width: 110 },
+    { field: 'username', headerName: 'User', width: 130 },
+    { field: 'submitted_at', headerName: 'Date', width: 170 },
     {
       field: 'auto_status',
       headerName: 'Autograde-Status',
@@ -312,7 +312,7 @@ export const GradingComponent = (props: IGradingProps) => {
         />
       )
     },
-    {field: 'score', headerName: 'Score', width: 130}
+    { field: 'score', headerName: 'Score', width: 130 }
   ];
   /**
    * Returns submission based on given rows.
@@ -325,10 +325,15 @@ export const GradingComponent = (props: IGradingProps) => {
     }
     const id = row.id;
     const submission = submissions.find(s => s.id === id);
-    console.log(submission);
     return submission === undefined ? null : submission;
   };
 
+  const allAutoGraded = (selection: IRowValues[]) => {
+    return selection.reduce((acc, cur) => {
+      return cur.auto_status === 'automatically_graded' && acc;
+    }, true);
+  };
+
   const allManualGraded = (selection: IRowValues[]) => {
     return selection.reduce((acc, cur) => {
       return cur.manual_status === 'manually_graded' && acc;
@@ -346,7 +351,6 @@ export const GradingComponent = (props: IGradingProps) => {
   };
 
   const openFile = async (path: string) => {
-    console.log('Opening file: ' + path);
     GlobalObjects.commands
       .execute('docmanager:open', {
         path: path,
@@ -358,7 +362,6 @@ export const GradingComponent = (props: IGradingProps) => {
         enqueueSnackbar(error.message, {
           variant: 'error'
         });
-        console.log(error);
       });
   };
   /**
@@ -372,7 +375,6 @@ export const GradingComponent = (props: IGradingProps) => {
         variant: 'success'
       });
     } catch (err) {
-      console.log(err);
       enqueueSnackbar('Error Exporting Submissions', {
         variant: 'error'
       });
@@ -382,18 +384,18 @@ export const GradingComponent = (props: IGradingProps) => {
   return (
     <div>
       <ModalTitle title="Grading">
-        <Box sx={{ml: 2}} display="inline-block">
+        <Box sx={{ ml: 2 }} display="inline-block">
           <Tooltip title="Reload">
             <IconButton aria-label="reload" onClick={updateSubmissions}>
-              <ReplayIcon/>
+              <ReplayIcon />
             </IconButton>
           </Tooltip>
         </Box>
       </ModalTitle>
-      <div style={{display: 'flex', height: '50vh', marginTop: '30px'}}>
-        <div style={{flexGrow: 1}}>
+      <div style={{ display: 'flex', height: '50vh', marginTop: '30px' }}>
+        <div style={{ flexGrow: 1 }}>
           <DataGrid
-            sx={{mb: 3, ml: 3, mr: 3}}
+            sx={{ mb: 3, ml: 3, mr: 3 }}
             columns={columns}
             rows={rows}
             checkboxSelection
@@ -410,8 +412,8 @@ export const GradingComponent = (props: IGradingProps) => {
           />
         </div>
       </div>
-      <span style={{height: '15vh'}}>
-        <FormControl sx={{m: 3}}>
+      <span style={{ height: '15vh' }}>
+        <FormControl sx={{ m: 3 }}>
           <InputLabel id="submission-select-label">View</InputLabel>
           <Select
             labelId="submission-select-label"
@@ -426,10 +428,13 @@ export const GradingComponent = (props: IGradingProps) => {
           </Select>
         </FormControl>
         <Tooltip
-          title={`Run Autograde Tests for ${selectedRows.length} Submission${selectedRows.length === 1 ? "" : "s"}`}>
+          title={`Run Autograde Tests for ${selectedRows.length} Submission${
+            selectedRows.length === 1 ? '' : 's'
+          }`}
+        >
           <Button
             disabled={selectedRows.length === 0}
-            sx={{m: 3}}
+            sx={{ m: 3 }}
             variant="outlined"
             onClick={handleAutogradeSubmissions}
           >
@@ -442,19 +447,19 @@ export const GradingComponent = (props: IGradingProps) => {
             selectedRowsData[0]?.auto_status !== 'automatically_graded'
               ? 'error'
               : selectedRowsData.length !== 1 ||
-              selectedRowsData[0]?.auto_status !== 'automatically_graded'
-                ? 'disabled'
-                : 'primary'
+                selectedRowsData[0]?.auto_status !== 'automatically_graded'
+              ? 'disabled'
+              : 'primary'
           }
-          sx={{mb: -1}}
+          sx={{ mb: -1 }}
         />
-        <Tooltip title={"Manually Grade Answers of Submission"}>
+        <Tooltip title={'Manually Grade Answers of Submission'}>
           <Button
             disabled={
               selectedRowsData.length !== 1 ||
               selectedRowsData[0]?.auto_status !== 'automatically_graded'
             }
-            sx={{m: 3}}
+            sx={{ m: 3 }}
             onClick={() => {
               cleanSelectedRows();
               setDisplayManualGrading(true);
@@ -469,20 +474,20 @@ export const GradingComponent = (props: IGradingProps) => {
             selectedRows.length === 0
               ? 'disabled'
               : allManualGraded(selectedRowsData) ||
-              props.assignment.automatic_grading === 'full_auto'
-                ? 'primary'
-                : 'error'
+                props.assignment.automatic_grading === 'full_auto'
+              ? 'primary'
+              : 'error'
           }
-          sx={{mb: -1}}
+          sx={{ mb: -1 }}
         />
-        <Tooltip title={"Generate and Publish Feedback"}>
+        <Tooltip title={'Generate and Publish Feedback'}>
           <Button
             disabled={
               selectedRows.length === 0 ||
               (props.assignment.automatic_grading !== 'full_auto' &&
-                !allManualGraded(selectedRowsData))
+                !allAutoGraded(selectedRowsData))
             }
-            sx={{m: 3}}
+            sx={{ m: 3 }}
             onClick={handleGenerateFeedback}
             variant="outlined"
           >
@@ -491,8 +496,8 @@ export const GradingComponent = (props: IGradingProps) => {
         </Tooltip>
 
         <Button
-          startIcon={<FileDownloadIcon/>}
-          sx={{m: 3}}
+          startIcon={<FileDownloadIcon />}
+          sx={{ m: 3 }}
           onClick={handleExportSubmissions}
           variant="outlined"
         >
@@ -527,7 +532,7 @@ export const GradingComponent = (props: IGradingProps) => {
         <DialogContent>
           <Typography
             id="alert-dialog-description"
-            sx={{fontSize: 10, fontFamily: "'Roboto Mono', monospace"}}
+            sx={{ fontSize: 10, fontFamily: "'Roboto Mono', monospace" }}
           >
             {logs}
           </Typography>
