@@ -103,18 +103,19 @@ export const Files = (props: IFilesProps) => {
         const modified = moment(newValue.last_modified).valueOf();
         if (srcChangedTimestamp === null || srcChangedTimestamp < modified) {
           setSrcChangeTimestamp(modified);
-          console.log('New source file changed timestamp: ' + modified);
         }
       },
       this
     );
 
-    getRemoteStatus(lecture, assignment, RepoType.SOURCE).then(status => {
-      setRepoStatus(
-        status as 'up_to_date' | 'pull_needed' | 'push_needed' | 'divergent'
-      );
-    });
-  }, [props]);
+    getRemoteStatus(props.lecture, props.assignment, RepoType.SOURCE).then(
+      status => {
+        setRepoStatus(
+          status as 'up_to_date' | 'pull_needed' | 'push_needed' | 'divergent'
+        );
+      }
+    );
+  }, [props.assignment, props.lecture]);
   /**
    * Reload file view.
    */
@@ -144,9 +145,12 @@ export const Files = (props: IFilesProps) => {
           setSelectedDir(dir);
         })
         .catch(error => {
-          enqueueSnackbar(error.message, {
-            variant: 'error'
-          });
+          enqueueSnackbar(
+            'Error Generating Student Version Notebooks: ' + error.message,
+            {
+              variant: 'error'
+            }
+          );
         });
     } else {
       setSelectedDir(dir);
@@ -174,7 +178,7 @@ export const Files = (props: IFilesProps) => {
             commitMessage
           );
         } catch (err) {
-          enqueueSnackbar('Error Pushing Assignment', {
+          enqueueSnackbar('Error Pushing Assignment: ' + err.message, {
             variant: 'error'
           });
           closeDialog();
@@ -292,7 +296,6 @@ export const Files = (props: IFilesProps) => {
   };
 
   const newUntitled = async () => {
-    console.log('Creating untitled notebook');
     const res = await GlobalObjects.docManager.newUntitled({
       type: 'notebook',
       path: `source/${lecture.code}/${assignment.id}`
@@ -352,7 +355,7 @@ export const Files = (props: IFilesProps) => {
               color={isCommitOverwrite() ? 'error' : 'primary'}
             >
               <PublishRoundedIcon fontSize="small" sx={{ mr: 1 }} />
-              Commit
+              Push
             </Button>
           </Tooltip>
         </CommitDialog>
