@@ -5,17 +5,61 @@
 // LICENSE file in the root directory of this source tree.
 
 import * as React from 'react';
-import { Cell } from '@jupyterlab/cells';
-import { CellModel, CellType } from '../model';
+import {Cell} from '@jupyterlab/cells';
+import {CellModel, CellType} from '../model';
 import {
   Alert,
   Box,
   Divider,
   Grid,
-  MenuItem,
+  MenuItem, styled, Switch,
   TextField
 } from '@mui/material';
-import { AntSwitch } from './creation-switch';
+
+export const AntSwitch = styled(Switch)(({theme}) => ({
+  width: 28,
+  height: 16,
+  padding: 0,
+  display: 'flex',
+  '&:active': {
+    '& .MuiSwitch-thumb': {
+      width: 15
+    },
+    '& .MuiSwitch-switchBase.Mui-checked': {
+      transform: 'translateX(9px)'
+    }
+  },
+  '& .MuiSwitch-switchBase': {
+    padding: 2,
+    '&.Mui-checked': {
+      transform: 'translateX(12px)',
+      color: '#fff',
+      '& + .MuiSwitch-track': {
+        opacity: 1,
+        backgroundColor: theme.palette.mode === 'dark' ? '#177ddc' : '#1890ff'
+      }
+    }
+  },
+  '& .MuiSwitch-thumb': {
+    boxShadow: '0 2px 4px 0 rgb(0 35 11 / 20%)',
+    width: 12,
+    height: 12,
+    borderRadius: 6,
+    transition: theme.transitions.create(['width'], {
+      duration: 200
+    })
+  },
+  '& .MuiSwitch-track': {
+    borderRadius: 16 / 2,
+    opacity: 1,
+    backgroundColor:
+      theme.palette.mode === 'dark'
+        ? 'rgba(255,255,255,.35)'
+        : 'rgba(0,0,0,.25)',
+    boxSizing: 'border-box'
+  }
+}));
+
 
 export interface ICreationComponentProps {
   cell: Cell;
@@ -69,7 +113,7 @@ export const CreationComponent = (props: ICreationComponentProps) => {
     updateMetadata();
   });
 
-  const alertStyle = { width: 250 };
+  const alertStyle = {width: 250};
   const gradableCell =
     type !== ('readonly' as CellType) &&
     type !== ('solution' as CellType) &&
@@ -78,15 +122,15 @@ export const CreationComponent = (props: ICreationComponentProps) => {
 
   return (
     <Box>
-      <Divider />
-      <Box sx={{ mt: 2, mb: 1, ml: 3 }}>
+      <Divider/>
+      <Box sx={{mt: 2, mb: 1, ml: 3}}>
         <Grid container spacing={1}>
           <Grid item>
             <TextField
               label="Type"
               select
               size="small"
-              sx={{ minWidth: 150 }}
+              sx={{minWidth: 150}}
               value={type}
               onChange={e => {
                 setType(e.target.value as CellType);
@@ -100,9 +144,10 @@ export const CreationComponent = (props: ICreationComponentProps) => {
               {props.cell.model.type === 'code' && (
                 <MenuItem value="tests">Autograded tests</MenuItem>
               )}
-
               <MenuItem value="manual">Manual graded answer</MenuItem>
-              <MenuItem value="task">Manual graded task</MenuItem>
+              {props.cell.model.type === 'markdown' && (
+                  <MenuItem value="task">Manual graded task</MenuItem>
+              )}
             </TextField>
           </Grid>
 
@@ -142,10 +187,10 @@ export const CreationComponent = (props: ICreationComponentProps) => {
           {solutionCell && (
             <Grid item>
               <AntSwitch
-                sx={{ mt: 2, ml: 1 }}
+                sx={{mt: 2, ml: 1}}
                 checked={hintChecked}
                 onChange={handleHintChange}
-                inputProps={{ 'aria-label': 'controlled' }}
+                inputProps={{'aria-label': 'controlled'}}
               />
             </Grid>
           )}
